# Functions that change from handling_data's functions
import os
from pathlib import Path
from typing import Union, List, Dict


def retrieve_nets_from_data_dict(data_dict: Dict,
                                 nets_by_sta: Dict[str, List[str]]) -> None:
    """
    Retrieve nets by sta_id from the given data_dict.

    :param data_dict: dict of data by station
    :param nets_by_sta: nets list by sta_id
    """
    for sta_id in data_dict.keys():
        if sta_id not in nets_by_sta:
            nets_by_sta[sta_id] = set()
        for c in data_dict[sta_id]:
            nets_by_sta[sta_id].update(
                data_dict[sta_id][c]['nets'])


def read_text(path2file: Path) -> Union[bool, str]:
    """
    CHANGED FROM handling_data.read_text:
        + Don't need to check binary because UnicodeDecodeError caught means
            the file is binary

    Read text file and add to log_data under channel TEXT.
        + Raise exception if the file isn't a text file
        + Remove empty lines in content
    :param path2file: str - absolute path to text file
    :param file_name: str - name of text file
    :param text_logs: holder to keep log string, refer to
        DataTypeModel.__init__.log_data['TEXT']
    """
    try:
        with open(path2file, 'r') as file:
            content = file.read().strip()
    except UnicodeDecodeError:
        return

    if content != '':
        # skip empty lines
        no_empty_line_list = [
            line for line in content.splitlines() if line]
        no_empty_line_content = os.linesep.join(no_empty_line_list)

        log_text = "\n\n** STATE OF HEALTH: %s\n" % path2file.name
        log_text += no_empty_line_content
    else:
        log_text = ''
    return log_text
